@@ -81,13 +81,13 @@ public:
 
   /* methods from Widget */
   virtual void Prepare(ContainerWindow &parent, const PixelRect &rc) override;
-  virtual bool Save(bool &changed, bool &require_restart) override;
+  virtual bool Save(bool &changed) override;
 
 protected:
   void UpdateTerrainPreview();
 
   /* methods from DataFieldListener */
-  virtual void OnModified(DataField &df);
+  virtual void OnModified(DataField &df) override;
 };
 
 /** XXX this hack is needed because the form callbacks don't get a
@@ -209,6 +209,11 @@ TerrainDisplayConfigPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
     { 9, N_("Vibrant"), },
     { 7, N_("Grey"), },
     { 8, N_("White"), },
+    {10, N_("Sandstone"), },
+    {11, N_("Pastel"), },
+    {12, N_("Italian Avioportolano VFR Chart"), },
+    {13, N_("German DFS VFR Chart"), },
+    {14, N_("French SIA VFR Chart"), },
     { 0 }
   };
 
@@ -260,11 +265,11 @@ TerrainDisplayConfigPanel::Prepare(ContainerWindow &parent, const PixelRect &rc)
 }
 
 bool
-TerrainDisplayConfigPanel::Save(bool &_changed, bool &_require_restart)
+TerrainDisplayConfigPanel::Save(bool &_changed)
 {
   MapSettings &settings_map = CommonInterface::SetMapSettings();
 
-  bool changed = false, require_restart = false;
+  bool changed = false;
   changed = (settings_map.terrain != terrain_settings);
 
   settings_map.terrain = terrain_settings;
@@ -278,7 +283,6 @@ TerrainDisplayConfigPanel::Save(bool &_changed, bool &_require_restart)
                        settings_map.topography_enabled);
 
   _changed |= changed;
-  _require_restart |= require_restart;
 
   return true;
 }
