@@ -26,11 +26,11 @@ Copyright_License {
 #include "Engine/GlideSolvers/GlideState.hpp"
 #include "Engine/GlideSolvers/MacCready.hpp"
 #include "Engine/GlideSolvers/GlideResult.hpp"
+#include "Engine/Util/Gradient.hpp"
 #include "NMEA/MoreData.hpp"
 #include "NMEA/Derived.hpp"
-#include "ComputerSettings.hpp"
+#include "Computer/Settings.hpp"
 #include "Math/SunEphemeris.hpp"
-#include "LocalTime.hpp"
 #include "Util/StaticString.hpp"
 #include "Util/Macros.hpp"
 #include "Language/Language.hpp"
@@ -57,7 +57,7 @@ FormatGlideResult(TCHAR *buffer, size_t size,
     return _("No solution");
   }
 
-  return NULL;
+  return nullptr;
 }
 
 void
@@ -67,8 +67,9 @@ WaypointInfoWidget::AddGlideResult(const TCHAR *label,
   const ComputerSettings &settings = CommonInterface::GetComputerSettings();
 
   TCHAR buffer[64];
-  AddReadOnly(label, NULL, FormatGlideResult(buffer, ARRAY_SIZE(buffer),
-                                             result, settings.task.glide));
+  AddReadOnly(label, nullptr,
+              FormatGlideResult(buffer, ARRAY_SIZE(buffer),
+                                result, settings.task.glide));
 }
 
 gcc_const
@@ -107,9 +108,9 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
 
   if (waypoint.radio_frequency.IsDefined() &&
       waypoint.radio_frequency.Format(buffer.buffer(),
-                                      buffer.MAX_SIZE) != NULL) {
+                                      buffer.MAX_SIZE) != nullptr) {
     buffer += _T(" MHz");
-    AddReadOnly(_("Radio frequency"), NULL, buffer);
+    AddReadOnly(_("Radio frequency"), nullptr, buffer);
   }
 
   if (waypoint.runway.IsDirectionDefined())
@@ -128,20 +129,20 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
   }
 
   if (!buffer.empty())
-    AddReadOnly(_("Runway"), NULL, buffer);
+    AddReadOnly(_("Runway"), nullptr, buffer);
 
   if (FormatGeoPoint(waypoint.location,
-                     buffer.buffer(), buffer.MAX_SIZE) != NULL)
-    AddReadOnly(_("Location"), NULL, buffer);
+                     buffer.buffer(), buffer.MAX_SIZE) != nullptr)
+    AddReadOnly(_("Location"), nullptr, buffer);
 
   FormatUserAltitude(waypoint.elevation,
                             buffer.buffer(), buffer.MAX_SIZE);
-  AddReadOnly(_("Elevation"), NULL, buffer);
+  AddReadOnly(_("Elevation"), nullptr, buffer);
 
   if (basic.time_available && basic.date_available) {
     const SunEphemeris::Result sun =
       SunEphemeris::CalcSunTimes(waypoint.location, basic.date_time_utc,
-                                 fixed(GetUTCOffset()) / 3600);
+                                 settings.utc_offset);
 
     const BrokenTime sunrise = BreakHourOfDay(sun.time_of_sunrise);
     const BrokenTime sunset = BreakHourOfDay(sun.time_of_sunset);
@@ -149,7 +150,7 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
     buffer.UnsafeFormat(_T("%02u:%02u - %02u:%02u"),
                         sunrise.hour, sunrise.minute,
                         sunset.hour, sunset.minute);
-    AddReadOnly(_("Daylight time"), NULL, buffer);
+    AddReadOnly(_("Daylight time"), nullptr, buffer);
   }
 
   if (basic.location_available) {
@@ -161,7 +162,7 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
 
     FormatBearing(buffer.buffer(), buffer.MAX_SIZE,
                   vector.bearing, distance_buffer);
-    AddReadOnly(_("Bearing and Distance"), NULL, buffer);
+    AddReadOnly(_("Bearing and Distance"), nullptr, buffer);
   }
 
   if (basic.location_available && basic.NavAltitudeAvailable() &&
@@ -187,4 +188,21 @@ WaypointInfoWidget::Prepare(ContainerWindow &parent, const PixelRect &rc)
                                     settings.polar.glide_polar_task,
                                     glide_state));
   }
+
+  if (basic.location_available && basic.NavAltitudeAvailable()) {
+    const TaskBehaviour &task_behaviour =
+      CommonInterface::GetComputerSettings().task;
+
+    const fixed safety_height = task_behaviour.safety_height_arrival;
+    const fixed target_altitude = waypoint.elevation + safety_height;
+    const fixed delta_h = basic.nav_altitude - target_altitude;
+    if (positive(delta_h)) {
+      const fixed distance = basic.location.Distance(waypoint.location);
+      const fixed gr = distance / delta_h;
+      if (GradientValid(gr)) {
+        buffer.UnsafeFormat(_T("%.1f"), (double)gr);
+        AddReadOnly(_("Required glide ratio"), nullptr, buffer);
+      }
+    }
+  }
 }
