@@ -28,11 +28,7 @@
 #include "Task/Ordered/Points/ASTPoint.hpp"
 #include "Task/Ordered/Points/FinishPoint.hpp"
 #include "Task/ObservationZones/LineSectorZone.hpp"
-#include "Task/ObservationZones/FAISectorZone.hpp"
 #include "Task/ObservationZones/KeyholeZone.hpp"
-#include "Task/ObservationZones/BGAFixedCourseZone.hpp"
-#include "Task/ObservationZones/BGAEnhancedOptionZone.hpp"
-#include "Task/ObservationZones/BGAStartSectorZone.hpp"
 #include "Task/ObservationZones/CylinderZone.hpp"
 #include "Task/ObservationZones/AnnularSectorZone.hpp"
 
@@ -42,16 +38,18 @@ static fixed
 GetOZSize(const ObservationZonePoint &oz)
 {
   switch (oz.GetShape()) {
-  case ObservationZonePoint::SECTOR:
+  case ObservationZone::Shape::SECTOR:
+  case ObservationZone::Shape::SYMMETRIC_QUADRANT:
     return ((const SectorZone &)oz).GetRadius();
 
-  case ObservationZonePoint::LINE:
+  case ObservationZone::Shape::LINE:
     return ((const LineSectorZone &)oz).GetLength();
 
-  case ObservationZonePoint::CYLINDER:
+  case ObservationZone::Shape::CYLINDER:
+  case ObservationZone::Shape::MAT_CYLINDER:
     return ((const CylinderZone &)oz).GetRadius();
 
-  case ObservationZonePoint::ANNULAR_SECTOR:
+  case ObservationZone::Shape::ANNULAR_SECTOR:
     return ((const AnnularSectorZone &)oz).GetRadius();
 
   default:
@@ -75,29 +73,19 @@ AbstractTaskFactory::GetMutatedPointType(const OrderedTaskPoint &tp) const
 
   switch (tp.GetType()) {
   case TaskPointType::START:
-    if (!IsValidStartType(newtype)) {
-      newtype = behaviour.sector_defaults.start_type;
-      if (!IsValidStartType(newtype))
-        newtype = *start_types.begin();
-    }
+    if (!IsValidStartType(newtype))
+      newtype = GetDefaultStartType();
     break;
 
   case TaskPointType::AST:
   case TaskPointType::AAT:
-    if (!IsValidIntermediateType(newtype)) {
-      newtype = behaviour.sector_defaults.turnpoint_type;
-      if (!IsValidIntermediateType(newtype)) {
-        newtype = *intermediate_types.begin();
-      }
-    }
+    if (!IsValidIntermediateType(newtype))
+      newtype = GetDefaultIntermediateType();
     break;
 
   case TaskPointType::FINISH:
-    if (!IsValidFinishType(newtype)) {
-      newtype = behaviour.sector_defaults.finish_type;
-      if (!IsValidFinishType(newtype))
-        newtype = *finish_types.begin();
-    }
+    if (!IsValidFinishType(newtype))
+      newtype = GetDefaultFinishType();
     break;
 
   case TaskPointType::UNORDERED:
@@ -139,11 +127,7 @@ AbstractTaskFactory::CreateASTPoint(ObservationZonePoint* oz,
 StartPoint* 
 AbstractTaskFactory::CreateStart(const Waypoint &wp) const
 {
-  TaskPointFactoryType type = behaviour.sector_defaults.start_type;
-  if (!IsValidStartType(type))
-    type = *start_types.begin();
-
-  return CreateStart(type, wp);
+  return CreateStart(GetDefaultStartType(), wp);
 }
 
 IntermediateTaskPoint* 
@@ -155,21 +139,13 @@ AbstractTaskFactory::CreateIntermediate(const Waypoint &wp) const
       return CreateIntermediate(type, wp);
   }
 
-  TaskPointFactoryType type = behaviour.sector_defaults.turnpoint_type;
-  if (!IsValidIntermediateType(type))
-    type = *intermediate_types.begin();
-
-  return CreateIntermediate(type, wp);
+  return CreateIntermediate(GetDefaultIntermediateType(), wp);
 }
 
 FinishPoint* 
 AbstractTaskFactory::CreateFinish(const Waypoint &wp) const
 {
-  TaskPointFactoryType type = behaviour.sector_defaults.finish_type;
-  if (!IsValidFinishType(type))
-    type = *finish_types.begin();
-
-  return CreateFinish(type, wp);
+  return CreateFinish(GetDefaultFinishType(), wp);
 }
 
 TaskPointFactoryType 
@@ -180,80 +156,98 @@ AbstractTaskFactory::GetType(const OrderedTaskPoint &point) const
   switch (point.GetType()) {
   case TaskPointType::START:
     switch (oz.GetShape()) {
-    case ObservationZonePoint::FAI_SECTOR:
+    case ObservationZone::Shape::FAI_SECTOR:
+    case ObservationZone::Shape::SYMMETRIC_QUADRANT:
       return TaskPointFactoryType::START_SECTOR;
 
-    case ObservationZonePoint::LINE:
+    case ObservationZone::Shape::LINE:
       return TaskPointFactoryType::START_LINE;
 
-    case ObservationZonePoint::CYLINDER:
-    case ObservationZonePoint::SECTOR:
-    case ObservationZonePoint::KEYHOLE:
-    case ObservationZonePoint::BGAFIXEDCOURSE:
-    case ObservationZonePoint::BGAENHANCEDOPTION:
-    case ObservationZonePoint::ANNULAR_SECTOR:
+    case ObservationZone::Shape::CYLINDER:
+    case ObservationZone::Shape::MAT_CYLINDER:
+    case ObservationZone::Shape::SECTOR:
+    case ObservationZone::Shape::DAEC_KEYHOLE:
+    case ObservationZone::Shape::CUSTOM_KEYHOLE:
+    case ObservationZone::Shape::BGAFIXEDCOURSE:
+    case ObservationZone::Shape::BGAENHANCEDOPTION:
+    case ObservationZone::Shape::ANNULAR_SECTOR:
       return TaskPointFactoryType::START_CYLINDER;
 
-    case ObservationZonePoint::BGA_START:
+    case ObservationZone::Shape::BGA_START:
       return TaskPointFactoryType::START_BGA;
     }
     break;
 
   case TaskPointType::AAT:
     switch (oz.GetShape()) {
-    case ObservationZonePoint::SECTOR:
-    case ObservationZonePoint::FAI_SECTOR:
-    case ObservationZonePoint::KEYHOLE:
-    case ObservationZonePoint::BGAFIXEDCOURSE:
-    case ObservationZonePoint::BGAENHANCEDOPTION:
-    case ObservationZonePoint::BGA_START:
-    case ObservationZonePoint::LINE:
+    case ObservationZone::Shape::SECTOR:
+    case ObservationZone::Shape::FAI_SECTOR:
+    case ObservationZone::Shape::SYMMETRIC_QUADRANT:
+    case ObservationZone::Shape::DAEC_KEYHOLE:
+    case ObservationZone::Shape::BGAFIXEDCOURSE:
+    case ObservationZone::Shape::BGAENHANCEDOPTION:
+    case ObservationZone::Shape::BGA_START:
+    case ObservationZone::Shape::LINE:
       return TaskPointFactoryType::AAT_SEGMENT;
-    case ObservationZonePoint::ANNULAR_SECTOR:
+    case ObservationZone::Shape::ANNULAR_SECTOR:
       return TaskPointFactoryType::AAT_ANNULAR_SECTOR;
-    case ObservationZonePoint::CYLINDER:
+    case ObservationZone::Shape::CYLINDER:
       return TaskPointFactoryType::AAT_CYLINDER;
+
+    case ObservationZone::Shape::CUSTOM_KEYHOLE:
+      return TaskPointFactoryType::AAT_KEYHOLE;
+
+    case ObservationZone::Shape::MAT_CYLINDER:
+      return TaskPointFactoryType::MAT_CYLINDER;
     }
     break;
 
   case TaskPointType::AST:
     switch (oz.GetShape()) {
-    case ObservationZonePoint::FAI_SECTOR:
+    case ObservationZone::Shape::FAI_SECTOR:
       return TaskPointFactoryType::FAI_SECTOR;
 
-    case ObservationZonePoint::KEYHOLE:
+    case ObservationZone::Shape::DAEC_KEYHOLE:
+    case ObservationZone::Shape::CUSTOM_KEYHOLE:
       return TaskPointFactoryType::KEYHOLE_SECTOR;
 
-    case ObservationZonePoint::BGAFIXEDCOURSE:
+    case ObservationZone::Shape::BGAFIXEDCOURSE:
       return TaskPointFactoryType::BGAFIXEDCOURSE_SECTOR;
 
-    case ObservationZonePoint::BGAENHANCEDOPTION:
+    case ObservationZone::Shape::BGAENHANCEDOPTION:
       return TaskPointFactoryType::BGAENHANCEDOPTION_SECTOR;
 
-    case ObservationZonePoint::BGA_START:
-    case ObservationZonePoint::CYLINDER:
-    case ObservationZonePoint::SECTOR:
-    case ObservationZonePoint::LINE:
-    case ObservationZonePoint::ANNULAR_SECTOR:
+    case ObservationZone::Shape::BGA_START:
+    case ObservationZone::Shape::CYLINDER:
+    case ObservationZone::Shape::MAT_CYLINDER:
+    case ObservationZone::Shape::SECTOR:
+    case ObservationZone::Shape::LINE:
+    case ObservationZone::Shape::ANNULAR_SECTOR:
       return TaskPointFactoryType::AST_CYLINDER;
+
+    case ObservationZone::Shape::SYMMETRIC_QUADRANT:
+      return TaskPointFactoryType::SYMMETRIC_QUADRANT;
     }
     break;
 
   case TaskPointType::FINISH:
     switch (oz.GetShape()) {
-    case ObservationZonePoint::BGA_START:
-    case ObservationZonePoint::FAI_SECTOR:
+    case ObservationZone::Shape::BGA_START:
+    case ObservationZone::Shape::FAI_SECTOR:
+    case ObservationZone::Shape::SYMMETRIC_QUADRANT:
       return TaskPointFactoryType::FINISH_SECTOR;
 
-    case ObservationZonePoint::LINE:
+    case ObservationZone::Shape::LINE:
       return TaskPointFactoryType::FINISH_LINE;
 
-    case ObservationZonePoint::CYLINDER:
-    case ObservationZonePoint::SECTOR:
-    case ObservationZonePoint::KEYHOLE:
-    case ObservationZonePoint::BGAFIXEDCOURSE:
-    case ObservationZonePoint::BGAENHANCEDOPTION:
-    case ObservationZonePoint::ANNULAR_SECTOR:
+    case ObservationZone::Shape::CYLINDER:
+    case ObservationZone::Shape::MAT_CYLINDER:
+    case ObservationZone::Shape::SECTOR:
+    case ObservationZone::Shape::DAEC_KEYHOLE:
+    case ObservationZone::Shape::CUSTOM_KEYHOLE:
+    case ObservationZone::Shape::BGAFIXEDCOURSE:
+    case ObservationZone::Shape::BGAENHANCEDOPTION:
+    case ObservationZone::Shape::ANNULAR_SECTOR:
       return TaskPointFactoryType::FINISH_CYLINDER;
     }
     break;
@@ -305,39 +299,58 @@ AbstractTaskFactory::CreatePoint(const TaskPointFactoryType type,
 
   switch (type) {
   case TaskPointFactoryType::START_SECTOR:
-    return CreateStart(new FAISectorZone(wp.location, false), wp);
+    return CreateStart(SymmetricSectorZone::CreateFAISectorZone(wp.location,
+                                                                false),
+                       wp);
   case TaskPointFactoryType::START_LINE:
     return CreateStart(new LineSectorZone(wp.location, start_radius), wp);
   case TaskPointFactoryType::START_CYLINDER:
     return CreateStart(new CylinderZone(wp.location, start_radius), wp);
   case TaskPointFactoryType::START_BGA:
-    return CreateStart(new BGAStartSectorZone(wp.location), wp);
+    return CreateStart(KeyholeZone::CreateBGAStartSectorZone(wp.location), wp);
   case TaskPointFactoryType::FAI_SECTOR:
-    return CreateASTPoint(new FAISectorZone(wp.location, true), wp);
+    return CreateASTPoint(SymmetricSectorZone::CreateFAISectorZone(wp.location,
+                                                                   true),
+                          wp);
+  case TaskPointFactoryType::SYMMETRIC_QUADRANT:
+    return CreateASTPoint(new SymmetricSectorZone(wp.location,
+                                                  turnpoint_radius), wp);
   case TaskPointFactoryType::KEYHOLE_SECTOR:
-    return CreateASTPoint(new KeyholeZone(wp.location), wp);
+    return CreateASTPoint(KeyholeZone::CreateDAeCKeyholeZone(wp.location), wp);
   case TaskPointFactoryType::BGAFIXEDCOURSE_SECTOR:
-    return CreateASTPoint(new BGAFixedCourseZone(wp.location), wp);
+    return CreateASTPoint(KeyholeZone::CreateBGAFixedCourseZone(wp.location), wp);
   case TaskPointFactoryType::BGAENHANCEDOPTION_SECTOR:
-    return CreateASTPoint(new BGAEnhancedOptionZone(wp.location), wp);
+    return CreateASTPoint(KeyholeZone::CreateBGAEnhancedOptionZone(wp.location), wp);
   case TaskPointFactoryType::AST_CYLINDER:
     return CreateASTPoint(new CylinderZone(wp.location, turnpoint_radius), wp);
+  case TaskPointFactoryType::MAT_CYLINDER:
+    return CreateAATPoint(CylinderZone::CreateMatCylinderZone(wp.location),
+                          wp);
   case TaskPointFactoryType::AAT_CYLINDER:
     return CreateAATPoint(new CylinderZone(wp.location, turnpoint_radius), wp);
   case TaskPointFactoryType::AAT_SEGMENT:
     return CreateAATPoint(new SectorZone(wp.location, turnpoint_radius), wp);
   case TaskPointFactoryType::AAT_ANNULAR_SECTOR:
     return CreateAATPoint(new AnnularSectorZone(wp.location, turnpoint_radius), wp);
+  case TaskPointFactoryType::AAT_KEYHOLE:
+    return CreateAATPoint(KeyholeZone::CreateCustomKeyholeZone(wp.location,
+                                                               turnpoint_radius,
+                                                               Angle::QuarterCircle()),
+                          wp);
   case TaskPointFactoryType::FINISH_SECTOR:
-    return CreateFinish(new FAISectorZone(wp.location, false), wp);
+    return CreateFinish(SymmetricSectorZone::CreateFAISectorZone(wp.location,
+                                                                 false),
+                        wp);
   case TaskPointFactoryType::FINISH_LINE:
     return CreateFinish(new LineSectorZone(wp.location, finish_radius), wp);
   case TaskPointFactoryType::FINISH_CYLINDER:
     return CreateFinish(new CylinderZone(wp.location, finish_radius), wp);
+
+  case TaskPointFactoryType::COUNT:
+    gcc_unreachable();
   }
 
-  assert(1);
-  return NULL;
+  gcc_unreachable();
 }
 
 StartPoint* 
@@ -624,6 +637,7 @@ AbstractTaskFactory::ValidAbstractType(LegalAbstractPointType type,
   case POINT_AAT:
     return is_intermediate &&
       (IsValidIntermediateType(TaskPointFactoryType::AAT_CYLINDER)
+       || IsValidIntermediateType(TaskPointFactoryType::MAT_CYLINDER)
        || IsValidIntermediateType(TaskPointFactoryType::AAT_SEGMENT)
        || IsValidIntermediateType(TaskPointFactoryType::AAT_ANNULAR_SECTOR));
   };
@@ -660,62 +674,51 @@ AbstractTaskFactory::IsValidType(const OrderedTaskPoint &new_tp,
   gcc_unreachable();
 }
 
-bool
-AbstractTaskFactory::IsValidIntermediateType(TaskPointFactoryType type) const
+TaskPointFactoryType
+AbstractTaskFactory::GetDefaultStartType() const
 {
-  return std::find(intermediate_types.begin(), intermediate_types.end(), type)
-    != intermediate_types.end();
+  TaskPointFactoryType type = behaviour.sector_defaults.start_type;
+  if (!IsValidStartType(type) && !start_types.IsEmpty())
+    type = start_types.UncheckedFirst();
+
+  return type;
 }
 
-bool
-AbstractTaskFactory::IsValidStartType(TaskPointFactoryType type) const
+TaskPointFactoryType
+AbstractTaskFactory::GetDefaultIntermediateType() const
 {
-  return std::find(start_types.begin(), start_types.end(), type)
-    != start_types.end();
+  TaskPointFactoryType type = behaviour.sector_defaults.turnpoint_type;
+  if (!IsValidIntermediateType(type) && !intermediate_types.IsEmpty())
+    type = intermediate_types.UncheckedFirst();
+
+  return type;
 }
 
-bool
-AbstractTaskFactory::IsValidFinishType(TaskPointFactoryType type) const
+TaskPointFactoryType
+AbstractTaskFactory::GetDefaultFinishType() const
 {
-  return std::find(finish_types.begin(), finish_types.end(), type)
-    != finish_types.end();
+  TaskPointFactoryType type = behaviour.sector_defaults.finish_type;
+  if (!IsValidFinishType(type) && !finish_types.IsEmpty())
+    type = finish_types.UncheckedFirst();
+
+  return type;
 }
 
-AbstractTaskFactory::LegalPointVector 
+LegalPointSet
 AbstractTaskFactory::GetValidTypes(unsigned position) const
 {
-  LegalPointVector v;
+  LegalPointSet v;
   if (ValidAbstractType(POINT_START, position))
-    v.insert(v.end(), start_types.begin(), start_types.end());
+    v |= start_types;
 
-  LegalPointVector i = GetValidIntermediateTypes(position);
-  if (!i.empty())
-    v.insert(v.end(), i.begin(), i.end());
+  v |= GetValidIntermediateTypes(position);
 
   if (ValidAbstractType(POINT_FINISH, position))
-    v.insert(v.end(), finish_types.begin(), finish_types.end());
+    v |= finish_types;
 
   return v;
 }
 
-void
-AbstractTaskFactory::AddValidationError(TaskValidationErrorType e)
-{
-  validation_errors.push_back(e);
-}
-
-void
-AbstractTaskFactory::ClearValidationErrors()
-{
-  validation_errors.clear();
-}
-
-TaskValidationErrorVector
-AbstractTaskFactory::GetValidationErrors()
-{
-  return validation_errors;
-}
-
 bool
 AbstractTaskFactory::CheckAddFinish()
 {
@@ -773,9 +776,12 @@ AbstractTaskFactory::ValidateFAIOZs()
     case TaskPointFactoryType::KEYHOLE_SECTOR:
     case TaskPointFactoryType::BGAFIXEDCOURSE_SECTOR:
     case TaskPointFactoryType::BGAENHANCEDOPTION_SECTOR:
+    case TaskPointFactoryType::MAT_CYLINDER:
     case TaskPointFactoryType::AAT_CYLINDER:
     case TaskPointFactoryType::AAT_SEGMENT:
     case TaskPointFactoryType::AAT_ANNULAR_SECTOR:
+    case TaskPointFactoryType::AAT_KEYHOLE:
+    case TaskPointFactoryType::SYMMETRIC_QUADRANT:
       valid = false;
       break;
 
@@ -790,6 +796,9 @@ AbstractTaskFactory::ValidateFAIOZs()
     case TaskPointFactoryType::FINISH_CYLINDER:
       valid = false;
       break;
+
+    case TaskPointFactoryType::COUNT:
+      gcc_unreachable();
     }
   }
 
@@ -799,6 +808,57 @@ AbstractTaskFactory::ValidateFAIOZs()
   return valid;
 }
 
+bool
+AbstractTaskFactory::ValidateMATOZs()
+{
+  ClearValidationErrors();
+  bool valid = true;
+
+  for (unsigned i = 0; i < task.TaskSize() && valid; i++) {
+    const OrderedTaskPoint &tp = task.GetPoint(i);
+
+    switch (GetType(tp)) {
+    case TaskPointFactoryType::START_CYLINDER:
+    case TaskPointFactoryType::START_LINE:
+    case TaskPointFactoryType::START_SECTOR:
+      break;
+
+    case TaskPointFactoryType::START_BGA:
+      valid = false;
+      break;
+
+    case TaskPointFactoryType::MAT_CYLINDER:
+      break;
+
+    case TaskPointFactoryType::AAT_CYLINDER:
+    case TaskPointFactoryType::FAI_SECTOR:
+    case TaskPointFactoryType::AST_CYLINDER:
+    case TaskPointFactoryType::KEYHOLE_SECTOR:
+    case TaskPointFactoryType::BGAFIXEDCOURSE_SECTOR:
+    case TaskPointFactoryType::BGAENHANCEDOPTION_SECTOR:
+    case TaskPointFactoryType::AAT_SEGMENT:
+    case TaskPointFactoryType::AAT_ANNULAR_SECTOR:
+    case TaskPointFactoryType::AAT_KEYHOLE:
+    case TaskPointFactoryType::FINISH_SECTOR:
+    case TaskPointFactoryType::SYMMETRIC_QUADRANT:
+      valid = false;
+      break;
+
+    case TaskPointFactoryType::FINISH_LINE:
+    case TaskPointFactoryType::FINISH_CYLINDER:
+      break;
+
+    case TaskPointFactoryType::COUNT:
+      gcc_unreachable();
+    }
+  }
+
+  if (!valid)
+    AddValidationError(TaskValidationErrorType::NON_MAT_OZS);
+
+  return valid;
+}
+
 bool
 AbstractTaskFactory::Validate()
 {
@@ -844,52 +904,24 @@ AbstractTaskFactory::Validate()
   return valid;
 }
 
-AbstractTaskFactory::LegalPointVector 
+LegalPointSet
 AbstractTaskFactory::GetValidIntermediateTypes(unsigned position) const
 {
-  LegalPointVector v;
-
   if (!IsPositionIntermediate(position))
-    return v;
+    return LegalPointSet();
 
   if (constraints.homogeneous_tps &&
       position > 1 && task.TaskSize() > 1) {
     TaskPointFactoryType type = GetType(task.GetPoint(1));
-    if (IsValidIntermediateType(type)) {
-      v.push_back(type);
-      return v;
-    }
+    if (IsValidIntermediateType(type))
+      return LegalPointSet(type);
   }
 
   if (ValidAbstractType(POINT_AAT, position) ||
       ValidAbstractType(POINT_AST, position))
-    v.insert(v.end(), intermediate_types.begin(), intermediate_types.end());
+    return intermediate_types;
 
-  return v;
-}
-
-AbstractTaskFactory::LegalPointVector
-AbstractTaskFactory::GetValidStartTypes() const
-{
-  LegalPointVector v;
-  v.insert(v.end(), start_types.begin(), start_types.end());
-  return v;
-}
-
-AbstractTaskFactory::LegalPointVector
-AbstractTaskFactory::GetValidIntermediateTypes() const
-{
-  LegalPointVector v;
-  v.insert(v.end(), intermediate_types.begin(), intermediate_types.end());
-  return v;
-}
-
-AbstractTaskFactory::LegalPointVector
-AbstractTaskFactory::GetValidFinishTypes() const
-{
-  LegalPointVector v;
-  v.insert(v.end(), finish_types.begin(), finish_types.end());
-  return v;
+  return LegalPointSet();
 }
 
 bool 
@@ -971,16 +1003,14 @@ AbstractTaskFactory::MutateTPsToTaskType()
   for (unsigned int i = 0; i < task.TaskSize(); i++) {
     const OrderedTaskPoint &tp = task.GetPoint(i);
     if (!IsValidType(tp, i) ||
+        task.GetFactoryType() == TaskFactoryType::MAT ||
         task.GetFactoryType() == TaskFactoryType::FAI_GENERAL) {
 
       TaskPointFactoryType newtype = GetMutatedPointType(tp);
       if (IsPositionFinish(i)) {
 
-        if (!IsValidFinishType(newtype)) {
-          newtype = behaviour.sector_defaults.finish_type;
-          if (!IsValidFinishType(newtype))
-            newtype = *finish_types.begin();
-        }
+        if (!IsValidFinishType(newtype))
+          newtype = GetDefaultFinishType();
 
         FinishPoint *fp = (FinishPoint*)CreateMutatedPoint(tp, newtype);
         assert(fp);
@@ -989,11 +1019,8 @@ AbstractTaskFactory::MutateTPsToTaskType()
         delete fp;
 
       } else if (i == 0) {
-        if (!IsValidStartType(newtype)) {
-          newtype = behaviour.sector_defaults.start_type;
-          if (!IsValidStartType(newtype))
-            newtype = *start_types.begin();
-        }
+        if (!IsValidStartType(newtype))
+          newtype = GetDefaultStartType();
 
         StartPoint *sp = (StartPoint*)CreateMutatedPoint(tp, newtype);
         assert(sp);
@@ -1003,11 +1030,9 @@ AbstractTaskFactory::MutateTPsToTaskType()
 
       } else {
 
-        if (!IsValidIntermediateType(newtype)) {
-          newtype = behaviour.sector_defaults.turnpoint_type;
-          if (!IsValidIntermediateType(newtype))
-            newtype = *intermediate_types.begin();
-        }
+        if (!IsValidIntermediateType(newtype))
+          newtype = GetDefaultIntermediateType();
+
         OrderedTaskPoint *tpnew = (OrderedTaskPoint*)CreateMutatedPoint(tp, newtype);
         if (Replace(*tpnew, i, true))
           changed = true;
