@@ -23,16 +23,6 @@
 #include "LineSectorZone.hpp"
 #include "Boundary.hpp"
 
-OZBoundary
-LineSectorZone::GetBoundary() const
-{
-  OZBoundary boundary;
-  boundary.push_front(GetSectorEnd());
-  boundary.push_front(GetSectorStart());
-  boundary.push_front(GetReference());
-  return boundary;
-}
-
 fixed
 LineSectorZone::ScoreAdjustment() const
 {
