@@ -42,7 +42,6 @@
 #include "Task/Factory/TaskFactoryConstraints.hpp"
 
 #include "Waypoint/Waypoints.hpp"
-
 #include "Geo/Flat/FlatBoundingBox.hpp"
 #include "Geo/GeoBounds.hpp"
 #include "Task/Stats/TaskSummary.hpp"
@@ -66,6 +65,7 @@ OrderedTask::OrderedTask(const TaskBehaviour &tb)
 OrderedTask::~OrderedTask()
 {
   RemoveAllPoints();
+  ClearMatPoints();
 
   delete active_factory;
 
@@ -119,6 +119,10 @@ OrderedTask::UpdateGeometry()
   for (const auto *tp : task_points)
     tp->ScanProjection(task_projection);
 
+  // scan location of mat control points
+  for (const auto *i : GetMatPoints())
+    i->ScanProjection(task_projection);
+
   // ... and optional start points
   for (const OrderedTaskPoint *tp : optional_start_points)
     tp->ScanProjection(task_projection);
@@ -128,10 +132,14 @@ OrderedTask::UpdateGeometry()
 
   // update OZ's for items that depend on next-point geometry 
   UpdateObservationZones(task_points, task_projection);
+  UpdateObservationZones(SetMatPoints(), task_projection);
   UpdateObservationZones(optional_start_points, task_projection);
 
   // now that the task projection is stable, and oz is stable,
   // calculate the bounding box in projected coordinates
+  for (const auto tp : GetMatPoints())
+    tp->UpdateBoundingBox(task_projection);
+
   for (const auto tp : task_points)
     tp->UpdateBoundingBox(task_projection);
 
@@ -287,6 +295,38 @@ OrderedTask::ScanDistancePlanned()
   return fixed(0);
 }
 
+unsigned
+OrderedTask::GetLastIntermediateAchieved() const
+{
+  if (TaskSize() < 2)
+    return 0;
+
+  for (unsigned i = 1; i < TaskSize() - 1; i++)
+    if (!task_points[i]->HasEntered())
+      return i - 1;
+  return TaskSize() - 2;
+}
+
+bool
+OrderedTask::ShouldAddToMat(const Waypoint &mat_wp) const
+{
+  unsigned last_achieved_index = GetLastIntermediateAchieved();
+
+  // is this the same point we just achieved? then ignore it
+  if (mat_wp == GetPoint(last_achieved_index).GetWaypoint())
+  {
+    return false;
+  }
+
+  // The TP after the last achieved is already next in the task
+  // and it is not the finish so do nothing
+  if ((last_achieved_index + 1 < TaskSize() -1)
+    && mat_wp == GetPoint(last_achieved_index + 1).GetWaypoint()) {
+    return false;
+  }
+  return true;
+}
+
 // TRANSITIONS
 
 bool 
@@ -311,8 +351,8 @@ OrderedTask::CheckTransitions(const AircraftState &state,
   FlatBoundingBox bb_now(task_projection.ProjectInteger(state.location),
                          1);
 
-  bool last_started = TaskStarted();
-  const bool last_finished = TaskFinished();
+  bool last_started = stats.start.task_started;
+  const bool last_finished = stats.task_finished;
 
   const int t_min = std::max(0, (int)active_task_point - 1);
   const int t_max = std::min(n_task - 1, (int)active_task_point);
@@ -343,12 +383,12 @@ OrderedTask::CheckTransitions(const AircraftState &state,
                                            transition_enter,
                                            transition_exit)) {
         task_advance.SetArmed(false);
-        
+
         if (i + 1 < n_task) {
           i++;
           SetActiveTaskPoint(i);
           taskpoint_start->ScanActive(*task_points[active_task_point]);
-          
+
           if (task_events != NULL)
             task_events->ActiveAdvanced(*task_points[i], i);
 
@@ -365,14 +405,19 @@ OrderedTask::CheckTransitions(const AircraftState &state,
 
   taskpoint_start->ScanActive(*task_points[active_task_point]);
 
-  stats.task_finished = TaskFinished();
-  stats.task_started = TaskStarted();
+  stats.task_finished = taskpoint_finish != nullptr &&
+    taskpoint_finish->HasEntered();
+  stats.start.task_started = TaskStarted();
 
-  if (stats.task_started)
-    taskpoint_finish->set_fai_finish_height(GetStartState().altitude - fixed(1000));
+  if (stats.start.task_started) {
+    const AircraftState start_state = taskpoint_start->GetEnteredState();
+    stats.start.SetStarted(start_state);
+
+    taskpoint_finish->set_fai_finish_height(start_state.altitude - fixed(1000));
+  }
 
   if (task_events != NULL) {
-    if (stats.task_started && !last_started)
+    if (stats.start.task_started && !last_started)
       task_events->TaskStart();
 
     if (stats.task_finished && !last_finished)
@@ -413,6 +458,17 @@ OrderedTask::CheckTransitionOptionalStart(const AircraftState &state,
   return full_update;
 }
 
+bool
+OrderedTask::CheckTransitionPointMat(OrderedTaskPoint &point,
+                                     const AircraftState &state,
+                                     const AircraftState &state_last,
+                                     const FlatBoundingBox &bb_now,
+                                     const FlatBoundingBox &bb_last)
+{
+  const bool nearby = point.BoundingBoxOverlaps(bb_now);
+
+  return nearby && point.CheckEnterTransitionMat(state, state_last);
+}
 
 bool
 OrderedTask::CheckTransitionPoint(OrderedTaskPoint &point,
@@ -488,6 +544,9 @@ OrderedTask::UpdateSample(const AircraftState &state,
                           const GlidePolar &glide_polar,
                            const bool full_update)
 {
+  stats.inside_oz = active_task_point < task_points.size() &&
+    task_points[active_task_point]->IsInSector(state);
+
   return true;
 }
 
@@ -953,20 +1012,11 @@ OrderedTask::Reset()
 
   AbstractTask::Reset();
   stats.task_finished = false;
-  stats.task_started = false;
+  stats.start.task_started = false;
   task_advance.Reset();
   SetActiveTaskPoint(0);
 }
 
-bool 
-OrderedTask::TaskFinished() const
-{
-  if (taskpoint_finish)
-    return (taskpoint_finish->HasEntered());
-
-  return false;
-}
-
 bool 
 OrderedTask::TaskStarted(bool soft) const
 {
@@ -1020,9 +1070,6 @@ OrderedTask::GetPointSearchPoints(unsigned tp) const
 void 
 OrderedTask::SetPointSearchMin(unsigned tp, const SearchPoint &sol)
 {
-  if (!tp && !task_points[0]->HasExited())
-    return;
-
   task_points[tp]->SetSearchMin(sol);
 }
 
@@ -1061,28 +1108,6 @@ OrderedTask::UpdateStartTransition(const AircraftState &state,
   // @todo: modify this for optional start?
 }
 
-AircraftState 
-OrderedTask::GetStartState() const
-{
-  if (HasStart() && TaskStarted())
-    return taskpoint_start->GetEnteredState();
-
-  // @todo: modify this for optional start?
-
-  AircraftState null_state;
-  return null_state;
-}
-
-AircraftState 
-OrderedTask::GetFinishState() const
-{
-  if (HasFinish() && TaskFinished())
-    return taskpoint_finish->GetEnteredState();
-
-  AircraftState null_state;
-  return null_state;
-}
-
 bool
 OrderedTask::HasTargets() const
 {
@@ -1093,15 +1118,6 @@ OrderedTask::HasTargets() const
   return false;
 }
 
-fixed
-OrderedTask::GetFinishHeight() const
-{
-  if (taskpoint_finish)
-    return taskpoint_finish->GetElevation();
-
-  return fixed(0);
-}
-
 GeoPoint 
 OrderedTask::GetTaskCenter() const
 {
@@ -1175,7 +1191,7 @@ OrderedTask::Commit(const OrderedTask& that)
   SetFactory(that.factory_mode);
 
   // copy across behaviour
-  ordered_behaviour = that.ordered_behaviour;
+  SetOrderedTaskBehaviour(that.ordered_behaviour);
 
   // remove if that task is smaller than this one
   while (TaskSize() > that.TaskSize()) {
@@ -1215,6 +1231,8 @@ OrderedTask::Commit(const OrderedTask& that)
     }
   }
 
+  mat_points.CloneFrom(that.mat_points, task_behaviour, ordered_behaviour);
+
   if (modified)
     UpdateGeometry();
     // @todo also re-scan task sample state,
@@ -1270,6 +1288,8 @@ OrderedTask::SetFactory(const TaskFactoryType the_factory)
   delete active_factory;
   active_factory = CreateTaskFactory(factory_mode, *this, task_behaviour);
   active_factory->UpdateOrderedTaskBehaviour(ordered_behaviour);
+
+  task_advance.SetFactoryConstraints(active_factory->GetConstraints());
 }
 
 void 
@@ -1297,6 +1317,7 @@ OrderedTask::GetFactoryTypes(bool all) const
   std::vector<TaskFactoryType> f_list;
   f_list.push_back(TaskFactoryType::RACING);
   f_list.push_back(TaskFactoryType::AAT);
+  f_list.push_back(TaskFactoryType::MAT);
   f_list.push_back(TaskFactoryType::FAI_GENERAL);
   return f_list;
 }
@@ -1405,3 +1426,19 @@ OrderedTask::UpdateSummary(TaskSummary& ordered_summary) const
     ordered_summary.update(stats.total.remaining.GetDistance(),
                            stats.total.planned.GetDistance());
 }
+
+void
+OrderedTask::FillMatPoints(const Waypoints &wps, bool update_geometry)
+{
+  ClearMatPoints();
+  GeoPoint center = TaskSize() > 0
+    ? GetPoint(0).GetLocation()
+    : task_projection.GetCenter();
+
+  if (GetFactoryType() == TaskFactoryType::MAT) {
+    mat_points.FillMatPoints(wps, GetFactory(), center);
+
+    if (update_geometry)
+      UpdateGeometry();
+  }
+}
