@@ -26,8 +26,9 @@
 #include "Geo/Flat/TaskProjection.hpp"
 #include "Task/AbstractTask.hpp"
 #include "Task/TaskBehaviour.hpp"
-#include "TaskAdvanceSmart.hpp"
+#include "SmartTaskAdvance.hpp"
 #include "Util/DereferenceIterator.hpp"
+#include "MatPoints.hpp"
 
 #include <assert.h>
 #include <vector>
@@ -81,10 +82,15 @@ private:
   TaskFactoryType factory_mode;
   AbstractTaskFactory* active_factory;
   OrderedTaskBehaviour ordered_behaviour;
-  TaskAdvanceSmart task_advance;
+  SmartTaskAdvance task_advance;
   TaskDijkstraMin *dijkstra_min;
   TaskDijkstraMax *dijkstra_max;
 
+  /**
+   * maintains a list of Turnpoints from the waypoint file for MAT tasks
+   */
+  MatPoints mat_points;
+
 public:
   /** 
    * Constructor.
@@ -158,6 +164,7 @@ public:
    * Copy task into this task
    *
    * @param other OrderedTask to copy
+   * @param waypoints.  const reference to the waypoint file
    * @return True if this task changed
    */
   bool Commit(const OrderedTask& other);
@@ -355,22 +362,6 @@ public:
     return task_projection;
   }
 
-  /**
-   * Accesses task start state
-   *
-   * @return State at task start (or null state if not started)
-   */
-  gcc_pure
-  AircraftState GetStartState() const;
-
-  /**
-   * Accesses task finish state
-   *
-   * @return State at task finish (or null state if not finished)
-   */
-  gcc_pure
-  AircraftState GetFinishState() const;
-
   void CheckDuplicateWaypoints(Waypoints& waypoints);
 
   /**
@@ -431,6 +422,7 @@ protected:
    */
   void set_tp_search_achieved(unsigned tp, const SearchPoint &sol);
 
+public:
   /**
    * Scan task for valid start/finish points
    *
@@ -438,6 +430,16 @@ protected:
    */
   bool ScanStartFinish();
 
+  /**
+   * checks if the aircraft has entered the Mat cylinder
+   * updates transition state of point
+   * @return true if enter transition occurs
+   */
+  bool CheckTransitionPointMat(OrderedTaskPoint &point,
+                               const AircraftState &state,
+                               const AircraftState &state_last,
+                               const FlatBoundingBox &bb_now,
+                               const FlatBoundingBox &bb_last);
 private:
 
   fixed ScanDistanceMin(const GeoPoint &ref, bool full);
@@ -531,7 +533,7 @@ public:
    * 
    * @return Reference to TaskAdvance used by this task
    */
-  TaskAdvance &GetTaskAdvance() {
+  TaskAdvance &SetTaskAdvance() {
     return task_advance;
   }
 
@@ -625,6 +627,57 @@ public:
   gcc_pure
   fixed GetTaskRadius() const;
 
+  /**
+   * returns the index of the highest intermediate TP that has been entered.
+   * if none have been entered, returns zero
+   * If start has exited, returns zero
+   * Does not consider whether Finish has been achieved
+   * @return index of last intermediate point achieved or 0 if none
+   */
+  unsigned GetLastIntermediateAchieved() const;
+
+  /**
+   * returns const reference to mat_points
+   */
+  const MatPoints::MatVector& GetMatPoints() const {
+    return mat_points.GetMatPoints();
+  }
+
+  /**
+   * returns reference mat_points
+   */
+  MatPoints::MatVector& SetMatPoints() {
+    return mat_points.SetMatPoints();
+  }
+
+  /**
+   * this is called automatically by Commit
+   * or if the waypoint file changes.
+   * If a client wants to use the Mat Points on an Uncommitted task,
+   * he must Call FillMatPoints himself
+   * The MatPoints will be deleted when the task is deleted
+   * It is the client's responsibility to lock the task manager if
+   * this is called on the active task
+   * @param wps.   Reference to the waypoint file
+   * @param update_geometry.  If true (default) will update the task's geometry
+   */
+  void FillMatPoints(const Waypoints &wps, bool update_geometry = true);
+
+  /**
+   * removes all points from mat_points
+   */
+  void ClearMatPoints() {
+    mat_points.ClearMatPoints();
+  }
+
+  /**
+   * Should we add this WP to the Mat
+   * after the last achieved Intermediate point?
+   * @param mat_wp the wp to test
+   * @return true if this should be added after the last achieved intermediate tp
+   */
+  bool ShouldAddToMat(const Waypoint &mat_wp) const;
+
 public:
   /* virtual methods from class TaskInterface */
   virtual unsigned TaskSize() const override {
@@ -639,10 +692,8 @@ public:
 
   /* virtual methods from class AbstractTask */
   virtual void Reset() override;
-  virtual bool TaskFinished() const override;
   virtual bool TaskStarted(bool soft=false) const override;
   virtual bool CheckTask() const override;
-  virtual fixed GetFinishHeight() const override;
 
 protected:
   /* virtual methods from class AbstractTask */
