@@ -22,22 +22,51 @@ Copyright_License {
 */
 
 #include "InfoBoxes/Content/Task.hpp"
+#include "InfoBoxes/Panel/Panel.hpp"
 #include "InfoBoxes/Data.hpp"
 #include "Interface.hpp"
 #include "Components.hpp"
 #include "Task/ProtectedTaskManager.hpp"
 #include "Dialogs/Waypoint/WaypointDialogs.hpp"
-#include "Dialogs/dlgAnalysis.hpp"
 #include "Engine/Util/Gradient.hpp"
+#include "Engine/Waypoint/Waypoint.hpp"
 #include "Units/Units.hpp"
 #include "Formatter/Units.hpp"
 #include "Formatter/TimeFormatter.hpp"
 #include "Language/Language.hpp"
-#include "UIGlobals.hpp"
+#include "Widget/CallbackWidget.hpp"
 
 #include <tchar.h>
 #include <stdio.h>
 
+static void
+ShowNextWaypointDetails()
+{
+  if (protected_task_manager == nullptr)
+    return;
+
+  const Waypoint *wp = protected_task_manager->GetActiveWaypoint();
+  if (wp == nullptr)
+    return;
+
+  dlgWaypointDetailsShowModal(*wp);
+}
+
+static Widget *
+LoadNextWaypointDetailsPanel(unsigned id)
+{
+  return new CallbackWidget(ShowNextWaypointDetails);
+}
+
+#ifdef __clang__
+/* gcc gives "redeclaration differs in 'constexpr'" */
+constexpr
+#endif
+const InfoBoxPanel next_waypoint_infobox_panels[] = {
+  { N_("Details"), LoadNextWaypointDetailsPanel },
+  { nullptr, nullptr }
+};
+
 void
 UpdateInfoBoxBearing(InfoBoxData &data)
 {
@@ -51,6 +80,7 @@ UpdateInfoBoxBearing(InfoBoxData &data)
 
   // Set Value
   data.SetValue(vector_remaining.bearing);
+  data.SetValueColor(task_stats.inside_oz ? 3 : 0);
 }
 
 void
@@ -67,6 +97,7 @@ UpdateInfoBoxBearingDiff(InfoBoxData &data)
 
   Angle Value = vector_remaining.bearing - basic.track;
   data.SetValueFromBearingDifference(Value);
+  data.SetValueColor(task_stats.inside_oz ? 3 : 0);
 }
 
 void
@@ -82,6 +113,9 @@ UpdateInfoBoxRadial(InfoBoxData &data)
 
   // Set Value
   data.SetValue(vector_remaining.bearing.Reciprocal());
+  data.SetValueColor(task_stats.inside_oz ? 3 : 0);
+
+  data.SetCommentFromDistance(vector_remaining.distance);
 }
 
 void
@@ -145,18 +179,17 @@ InfoBoxContentNextWaypoint::HandleKey(const InfoBoxKeyCodes keycode)
   case ibkDown:
     protected_task_manager->IncrementActiveTaskPoint(-1);
     return true;
-
-  case ibkEnter:
-    const Waypoint *wp = protected_task_manager->GetActiveWaypoint();
-    if (wp) {
-      dlgWaypointDetailsShowModal(UIGlobals::GetMainWindow(), *wp);
-      return true;
-    }
   }
 
   return false;
 }
 
+const InfoBoxPanel *
+InfoBoxContentNextWaypoint::GetDialogContent()
+{
+  return next_waypoint_infobox_panels;
+}
+
 void
 UpdateInfoBoxNextDistance(InfoBoxData &data)
 {
@@ -182,6 +215,7 @@ UpdateInfoBoxNextDistance(InfoBoxData &data)
 
   // Set Value
   data.SetValueFromDistance(vector_remaining.distance);
+  data.SetValueColor(task_stats.inside_oz ? 3 : 0);
 
   if (basic.track_available) {
     Angle bd = vector_remaining.bearing - basic.track;
@@ -480,69 +514,6 @@ UpdateInfoBoxFinalGR(InfoBoxData &data)
     data.SetInvalid();
 }
 
-void
-UpdateInfoBoxHomeDistance(InfoBoxData &data)
-{
-  const NMEAInfo &basic = CommonInterface::Basic();
-  const CommonStats &common_stats = CommonInterface::Calculated().common_stats;
-
-  if (!common_stats.vector_home.IsValid()) {
-    data.SetInvalid();
-    return;
-  }
-
-  // Set Value
-  data.SetValueFromDistance(common_stats.vector_home.distance);
-
-  if (basic.track_available) {
-    Angle bd = common_stats.vector_home.bearing - basic.track;
-    data.SetCommentFromBearingDifference(bd);
-  } else
-    data.SetCommentInvalid();
-}
-
-void
-InfoBoxContentOLC::Update(InfoBoxData &data)
-{
-  if (!CommonInterface::GetComputerSettings().contest.enable ||
-      !protected_task_manager) {
-    data.SetInvalid();
-    return;
-  }
-
-  const ContestResult& result_olc = 
-    CommonInterface::Calculated().contest_stats.GetResult();
-
-  if (result_olc.score < fixed(1)) {
-    data.SetInvalid();
-    return;
-  }
-
-  // Set Value
-  data.SetValueFromDistance(result_olc.distance);
-
-  data.UnsafeFormatComment(_T("%.1f pts"), (double)result_olc.score);
-}
-
-bool
-InfoBoxContentOLC::HandleKey(const InfoBoxKeyCodes keycode)
-{
-  switch (keycode) {
-  case ibkEnter:
-    dlgAnalysisShowModal(UIGlobals::GetMainWindow(), UIGlobals::GetLook(),
-                         CommonInterface::Full(), *glide_computer,
-                         protected_task_manager,
-                         &airspace_database,
-                         terrain, 8);
-    return true;
-
-  default:
-    break;
-  }
-
-  return false;
-}
-
 void
 UpdateInfoBoxTaskAATime(InfoBoxData &data)
 {
@@ -809,7 +780,7 @@ void
 UpdateInfoBoxCruiseEfficiency(InfoBoxData &data)
 {
   const TaskStats &task_stats = CommonInterface::Calculated().task_stats;
-  if (!task_stats.task_valid || !task_stats.task_started) {
+  if (!task_stats.task_valid || !task_stats.start.task_started) {
     data.SetInvalid();
     return;
   }
