@@ -28,13 +28,14 @@ Copyright_License {
 #include "MainWindow.hpp"
 #include "Interface.hpp"
 #include "Gauge/BigTrafficWidget.hpp"
-#include "ComputerSettings.hpp"
+#include "Computer/Settings.hpp"
 #include "Components.hpp"
 #include "MapSettings.hpp"
 #include "Simulator.hpp"
 #include "Waypoint/Waypoints.hpp"
 #include "Engine/Airspace/Airspaces.hpp"
 #include "Task/ProtectedTaskManager.hpp"
+#include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "Device/device.hpp"
 #include "PageActions.hpp"
 #include "Util/StringUtil.hpp"
@@ -221,7 +222,7 @@ ExpandTaskMacros(TCHAR *OutBuffer, size_t Size,
     } else if (_tcsstr(OutBuffer, _T("$(WaypointNextArm)"))) {
       // Waypoint\nNext
 
-      switch (task_manager->GetTaskAdvance().GetState()) {
+      switch (task_manager->GetOrderedTask().GetTaskAdvance().GetState()) {
       case TaskAdvance::MANUAL:
       case TaskAdvance::AUTO:
       case TaskAdvance::START_ARMED:
@@ -244,7 +245,7 @@ ExpandTaskMacros(TCHAR *OutBuffer, size_t Size,
 
     } else if (_tcsstr(OutBuffer, _T("$(WaypointPreviousArm)"))) {
 
-      switch (task_manager->GetTaskAdvance().GetState()) {
+      switch (task_manager->GetOrderedTask().GetTaskAdvance().GetState()) {
       case TaskAdvance::MANUAL:
       case TaskAdvance::AUTO:
       case TaskAdvance::START_DISARMED:
@@ -276,7 +277,7 @@ ExpandTaskMacros(TCHAR *OutBuffer, size_t Size,
   }
 
   if (_tcsstr(OutBuffer, _T("$(AdvanceArmed)"))) {
-    switch (task_manager->GetTaskAdvance().GetState()) {
+    switch (task_manager->GetOrderedTask().GetTaskAdvance().GetState()) {
     case TaskAdvance::MANUAL:
       ReplaceInString(OutBuffer, _T("$(AdvanceArmed)"), 
                       _("Advance\n(manual)"), Size);
@@ -551,10 +552,14 @@ ButtonLabel::ExpandMacros(const TCHAR *In, TCHAR *OutBuffer, size_t Size)
                       _("Off"), _("On"), Size);
 
   if (_tcsstr(OutBuffer, _T("$(MapLabelsToggleActionName)"))) {
-    static const TCHAR *const labels[] = { N_("All"),
-                                           N_("Task & Landables"),
-                                           N_("Task"),
-                                           N_("None") };
+    static const TCHAR *const labels[] = {
+      N_("All"),
+      N_("Task & Landables"),
+      N_("Task"),
+      N_("None"),
+      N_("Task & Airfields"),
+    };
+
     static constexpr unsigned int n = ARRAY_SIZE(labels);
     unsigned int i = (unsigned)GetMapSettings().waypoint.label_selection;
     ReplaceInString(OutBuffer, _T("$(MapLabelsToggleActionName)"),
