@@ -90,6 +90,7 @@ Copyright_License {
 
 #include "Task/TaskManager.hpp"
 #include "Task/ProtectedTaskManager.hpp"
+#include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "GlideSolvers/GlidePolar.hpp"
 #include "Operation/VerboseOperationEnvironment.hpp"
 #include "PageActions.hpp"
@@ -157,6 +158,8 @@ AfterStartup()
       defaultTask->CheckDuplicateWaypoints(way_points);
       way_points.Optimise();
     }
+
+    defaultTask->FillMatPoints(way_points);
     protected_task_manager->TaskCommit(*defaultTask);
     delete defaultTask;
   }
@@ -213,13 +216,14 @@ Startup()
 #ifdef HAVE_EGL
             "egl=%d "
 #endif
-            "npot=%d vbo=%d fbo=%d",
+            "npot=%d vbo=%d fbo=%d stencil=%#x",
 #ifdef HAVE_EGL
              OpenGL::egl,
 #endif
              OpenGL::texture_non_power_of_two,
              OpenGL::vertex_buffer_object,
-             OpenGL::frame_buffer_object);
+            OpenGL::frame_buffer_object,
+            OpenGL::render_buffer_stencil);
 #endif
 
   main_window->Initialise();
