@@ -24,6 +24,8 @@ Copyright_License {
 #include "Dialogs/Message.hpp"
 #include "Dialogs/TextEntry.hpp"
 #include "Dialogs/TimeEntry.hpp"
+#include "Dialogs/GeoPointEntry.hpp"
+#include "Time/RoughTime.hpp"
 
 int
 ShowMessageBox(const TCHAR *lpText, const TCHAR *lpCaption, unsigned uType)
@@ -32,15 +34,23 @@ ShowMessageBox(const TCHAR *lpText, const TCHAR *lpCaption, unsigned uType)
 }
 
 bool
-dlgTextEntryShowModal(TCHAR *text, size_t size,
-                      const TCHAR *caption,
-                      AllowedCharacters accb)
+TextEntryDialog(TCHAR *text, size_t size,
+                const TCHAR *caption,
+                AllowedCharacters accb)
 {
   return false;
 }
 
 bool
-TimeEntryDialog(const TCHAR *caption, RoughTime &value, bool nullable)
+TimeEntryDialog(const TCHAR *caption, RoughTime &value,
+                RoughTimeDelta time_zone, bool nullable)
+{
+  return false;
+}
+
+bool
+GeoPointEntryDialog(const TCHAR *caption, GeoPoint &value,
+                    bool nullable)
 {
   return false;
 }
