@@ -25,24 +25,23 @@
 
 #include "Task/Factory/AbstractTaskFactory.hpp"
 #include "Task/Factory/TaskFactoryConstraints.hpp"
+#include "Engine/Task/Ordered/OrderedTask.hpp"
 #include "Engine/Task/Ordered/Points/StartPoint.hpp"
 #include "Engine/Task/Ordered/Points/FinishPoint.hpp"
 #include "Engine/Task/Ordered/Points/ASTPoint.hpp"
 #include "Engine/Task/Ordered/Points/AATPoint.hpp"
 #include "Task/ObservationZones/CylinderZone.hpp"
+#include "Task/ObservationZones/SymmetricSectorZone.hpp"
 #include "Task/Visitors/TaskPointVisitor.hpp"
 #include "Engine/Waypoint/Waypoints.hpp"
+#include "Util/StaticArray.hpp"
 
 #include "harness_waypoints.hpp"
 #include <string.h>
 
-class FAISectorZone;
 class SectorZone;
 class LineSectorZone;
 class KeyholeZone;
-class BGAFixedCourseZone;
-class BGAEnhancedOptionZone;
-class BGAStartSectorZone;
 class AnnularSectorZone;
 
 class ObservationZoneVisitorPrint
@@ -51,9 +50,6 @@ public:
   void Visit(const KeyholeZone& oz) {
     printf("# kehole zone\n");
   }
-  void Visit(const FAISectorZone& oz) {
-    printf("# fai sect zone\n");
-  }
   void Visit(const SectorZone& oz) {
     printf("# sector zone\n");
   }
@@ -66,53 +62,42 @@ public:
   void Visit(const CylinderZone& oz) {
     printf("# cylinder zone\n");
   }
-  void Visit(const BGAFixedCourseZone &oz) {
-    printf("# bga fixed course zone\n");
-  }
-  void Visit(const BGAEnhancedOptionZone &oz) {
-    printf("# bga enhanded option zone\n");
-  }
-  void Visit(const BGAStartSectorZone &oz) {
-    printf("# bga start sector zone\n");
+
+  void Visit(const SymmetricSectorZone &oz) {
+    printf("# symmetric quadrant\n");
   }
 
   void Visit(const ObservationZonePoint &oz) {
     switch (oz.GetShape()) {
-    case ObservationZonePoint::FAI_SECTOR:
-      Visit((const FAISectorZone &)oz);
-      break;
-
-    case ObservationZonePoint::SECTOR:
+    case ObservationZone::Shape::FAI_SECTOR:
+    case ObservationZone::Shape::SECTOR:
       Visit((const SectorZone &)oz);
       break;
 
-    case ObservationZonePoint::LINE:
+    case ObservationZone::Shape::LINE:
       Visit((const LineSectorZone &)oz);
       break;
 
-    case ObservationZonePoint::CYLINDER:
+    case ObservationZone::Shape::MAT_CYLINDER:
+    case ObservationZone::Shape::CYLINDER:
       Visit((const CylinderZone &)oz);
       break;
 
-    case ObservationZonePoint::KEYHOLE:
+    case ObservationZone::Shape::CUSTOM_KEYHOLE:
+    case ObservationZone::Shape::DAEC_KEYHOLE:
+    case ObservationZone::Shape::BGAFIXEDCOURSE:
+    case ObservationZone::Shape::BGAENHANCEDOPTION:
+    case ObservationZone::Shape::BGA_START:
       Visit((const KeyholeZone &)oz);
       break;
 
-    case ObservationZonePoint::BGAFIXEDCOURSE:
-      Visit((const BGAFixedCourseZone &)oz);
-      break;
-
-    case ObservationZonePoint::BGAENHANCEDOPTION:
-      Visit((const BGAEnhancedOptionZone &)oz);
-      break;
-
-    case ObservationZonePoint::BGA_START:
-      Visit((const BGAStartSectorZone &)oz);
-      break;
-
-    case ObservationZonePoint::ANNULAR_SECTOR:
+    case ObservationZone::Shape::ANNULAR_SECTOR:
       Visit((const AnnularSectorZone &)oz);
       break;
+
+    case ObservationZone::Shape::SYMMETRIC_QUADRANT:
+      Visit((const SymmetricSectorZone &)oz);
+      break;
     }
   }
 };
@@ -331,7 +316,7 @@ bool test_task_type_manip(TaskManager& task_manager,
   if (!test_task_random_RT_AAT_FAI(task_manager, waypoints, n_points))
     return false;
 
-  switch (rand() %3) {
+  switch (rand() %4) {
   case 0:
     task_manager.SetFactory(TaskFactoryType::AAT);
     test_note("# switched FACTORY TYPE to AAT\n");
@@ -344,6 +329,10 @@ bool test_task_type_manip(TaskManager& task_manager,
     task_manager.SetFactory(TaskFactoryType::FAI_GENERAL);
     test_note("# switched FACTORY TYPE to FAI GENERAL\n");
     break;
+  case 3:
+    task_manager.SetFactory(TaskFactoryType::MAT);
+    test_note("# switched FACTORY TYPE to MAT\n");
+    break;
   default:
     test_note("# unknown task type\n");
   }
@@ -389,6 +378,12 @@ bool test_task_type_manip(TaskManager& task_manager,
       return false;
   }
 
+  if (task_manager.GetOrderedTask().GetFactoryType() ==
+                                      TaskFactoryType::MAT) {
+    test_note("# checking OZs for MAT task..\n");
+    if (!fact.ValidateMATOZs())
+      return false;
+  }
   return true;
 }
 
@@ -408,7 +403,7 @@ bool test_task_mixed(TaskManager& task_manager,
   wp = waypoints.LookupId(1);
   if (wp) {
     tp = fact.CreateStart(TaskPointFactoryType::START_LINE,*wp);
-    if (tp->GetObservationZone().GetShape() == ObservationZonePoint::CYLINDER) {
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::CYLINDER) {
       CylinderZone &cz = (CylinderZone &)tp->GetObservationZone();
       cz.SetRadius(fixed(5000.0));
       tp->UpdateOZ(projection);
@@ -436,7 +431,7 @@ bool test_task_mixed(TaskManager& task_manager,
   wp = waypoints.LookupId(3);
   if (wp) {
     tp = fact.CreateIntermediate(TaskPointFactoryType::AAT_CYLINDER,*wp);
-    if (tp->GetObservationZone().GetShape() == ObservationZonePoint::CYLINDER) {
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::CYLINDER) {
       CylinderZone &cz = (CylinderZone &)tp->GetObservationZone();
       cz.SetRadius(fixed(30000.0));
       tp->UpdateOZ(projection);
@@ -461,7 +456,7 @@ bool test_task_mixed(TaskManager& task_manager,
   wp = waypoints.LookupId(5);
   if (wp) {
     tp = fact.CreateIntermediate(TaskPointFactoryType::AAT_CYLINDER,*wp);
-    if (tp->GetObservationZone().GetShape() == ObservationZonePoint::CYLINDER) {
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::CYLINDER) {
       CylinderZone &cz = (CylinderZone &)tp->GetObservationZone();
       cz.SetRadius(fixed(30000.0));
       tp->UpdateOZ(projection);
@@ -583,7 +578,7 @@ bool test_task_aat(TaskManager& task_manager,
   wp = waypoints.LookupId(2);
   if (wp) {
     OrderedTaskPoint* tp = fact.CreateIntermediate(TaskPointFactoryType::AAT_CYLINDER,*wp);
-    if (tp->GetObservationZone().GetShape() == ObservationZonePoint::CYLINDER) {
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::CYLINDER) {
       CylinderZone &cz = (CylinderZone &)tp->GetObservationZone();
       cz.SetRadius(fixed(30000.0));
       tp->UpdateOZ(projection);
@@ -598,7 +593,7 @@ bool test_task_aat(TaskManager& task_manager,
   wp = waypoints.LookupId(3);
   if (wp) {
     OrderedTaskPoint* tp = fact.CreateIntermediate(TaskPointFactoryType::AAT_CYLINDER,*wp);
-    if (tp->GetObservationZone().GetShape() == ObservationZonePoint::CYLINDER) {
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::CYLINDER) {
       CylinderZone &cz = (CylinderZone &)tp->GetObservationZone();
       cz.SetRadius(fixed(40000.0));
       tp->UpdateOZ(projection);
@@ -630,6 +625,76 @@ bool test_task_aat(TaskManager& task_manager,
   return true;
 }
 
+static bool
+test_task_mat(TaskManager &task_manager, const Waypoints &waypoints)
+{
+  const TaskProjection &projection =
+    task_manager.GetOrderedTask().GetTaskProjection();
+
+  task_manager.SetFactory(TaskFactoryType::MAT);
+  AbstractTaskFactory &fact = task_manager.GetFactory();
+  const Waypoint *wp;
+
+  task_report(task_manager, "# adding start\n");
+  wp = waypoints.LookupId(1);
+  if (wp) {
+    OrderedTaskPoint *tp = fact.CreateStart(*wp);
+    if (!fact.Append(*tp,false)) {
+      return false;
+    }
+    delete tp;
+  }
+
+  task_manager.SetActiveTaskPoint(0);
+  task_manager.Resume();
+
+  task_report(task_manager, "# adding intermediate\n");
+  wp = waypoints.LookupId(2);
+  if (wp) {
+    OrderedTaskPoint* tp = fact.CreateIntermediate(TaskPointFactoryType::MAT_CYLINDER,*wp);
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::MAT_CYLINDER) {
+      tp->UpdateOZ(projection);
+    }
+    if (!fact.Append(*tp,false)) {
+      return false;
+    }
+    delete tp;
+  }
+
+  task_report(task_manager, "# adding intermediate\n");
+  wp = waypoints.LookupId(3);
+  if (wp) {
+    OrderedTaskPoint* tp = fact.CreateIntermediate(TaskPointFactoryType::MAT_CYLINDER,*wp);
+    if (tp->GetObservationZone().GetShape() == ObservationZone::Shape::MAT_CYLINDER) {
+      tp->UpdateOZ(projection);
+    }
+    if (!fact.Append(*tp,false)) {
+      return false;
+    }
+    delete tp;
+  }
+
+  task_report(task_manager, "# adding finish\n");
+  wp = waypoints.LookupId(1);
+  if (wp) {
+    OrderedTaskPoint *tp = fact.CreateFinish(*wp);
+    if (!fact.Append(*tp,false)) {
+      return false;
+    }
+    delete tp;
+  }
+
+  task_report(task_manager, "# checking task..\n");
+  if (!fact.Validate()) {
+    return false;
+  }
+
+  if (!task_manager.CheckOrderedTask()) {
+    return false;
+  }
+  return true;
+}
+
 
 bool test_task_or(TaskManager& task_manager,
                      const Waypoints &waypoints)
@@ -782,6 +847,14 @@ const Waypoint* random_waypoint(const Waypoints &waypoints) {
   return waypoints.LookupId(id);  
 }
 
+static TaskPointFactoryType
+GetRandomType(const LegalPointSet &l)
+{
+  StaticArray<TaskPointFactoryType, LegalPointSet::N> types;
+  l.CopyTo(std::back_inserter(types));
+  return types[(rand() % types.size())];
+}
+
 bool test_task_random(TaskManager& task_manager,
                       const Waypoints &waypoints,
                       const unsigned num_points)
@@ -796,8 +869,7 @@ bool test_task_random(TaskManager& task_manager,
   task_report(task_manager, "# adding start\n");
   wp = random_waypoint(waypoints);
   if (wp) {
-    TaskPointFactoryType s =
-      fact.GetStartTypes()[(rand() % fact.GetStartTypes().size())];
+    const TaskPointFactoryType s = GetRandomType(fact.GetStartTypes());
 
     tp = fact.CreateStart(s,*wp);
     if (!fact.Append(*tp,false)) {
@@ -813,8 +885,7 @@ bool test_task_random(TaskManager& task_manager,
     task_report(task_manager, "# adding intermediate\n");
     wp = random_waypoint(waypoints);
     if (wp) {
-      TaskPointFactoryType s =
-        fact.GetIntermediateTypes()[(rand() % fact.GetIntermediateTypes().size())];
+      const TaskPointFactoryType s = GetRandomType(fact.GetIntermediateTypes());
 
       tp = fact.CreateIntermediate(s,*wp);
       if (!fact.Append(*tp,false)) {
@@ -827,8 +898,7 @@ bool test_task_random(TaskManager& task_manager,
   task_report(task_manager, "# adding finish\n");
   wp = random_waypoint(waypoints);
   if (wp) {
-    TaskPointFactoryType s =
-      fact.GetFinishTypes()[(rand() % fact.GetFinishTypes().size())];
+    const TaskPointFactoryType s = GetRandomType(fact.GetFinishTypes());
 
     tp = fact.CreateFinish(s,*wp);
     if (!fact.Append(*tp,false)) {
@@ -891,8 +961,7 @@ bool test_task_random_RT_AAT_FAI(TaskManager& task_manager,
   test_note("# adding start\n");
   wp = random_waypoint(waypoints);
   if (wp) {
-    TaskPointFactoryType s =
-      fact.GetStartTypes()[(rand() % fact.GetStartTypes().size())];
+    const TaskPointFactoryType s = GetRandomType(fact.GetStartTypes());
 
     tp = fact.CreateStart(s,*wp);
     if (!fact.Append(*tp,false)) {
@@ -905,8 +974,7 @@ bool test_task_random_RT_AAT_FAI(TaskManager& task_manager,
     test_note("# adding intermediate\n");
     wp = random_waypoint(waypoints);
     if (wp) {
-      TaskPointFactoryType s =
-        fact.GetIntermediateTypes()[(rand() % fact.GetIntermediateTypes().size())];
+      const TaskPointFactoryType s = GetRandomType(fact.GetIntermediateTypes());
 
       tp = fact.CreateIntermediate(s,*wp);
       if (!fact.Append(*tp,false)) {
@@ -919,8 +987,7 @@ bool test_task_random_RT_AAT_FAI(TaskManager& task_manager,
   test_note("# adding finish\n");
   wp = random_waypoint(waypoints);
   if (wp) {
-    TaskPointFactoryType s =
-      fact.GetFinishTypes()[(rand() % fact.GetFinishTypes().size())];
+    const TaskPointFactoryType s = GetRandomType(fact.GetFinishTypes());
 
     tp = fact.CreateFinish(s,*wp);
     if (!fact.Append(*tp,false)) {
@@ -941,6 +1008,13 @@ bool test_task_random_RT_AAT_FAI(TaskManager& task_manager,
       return false;
   }
 
+  if (task_manager.GetOrderedTask().GetFactoryType()
+      == TaskFactoryType::MAT)
+  {
+    test_note("# checking OZs for MAT General..\n");
+    if (!fact.ValidateMATOZs())
+      return false;
+  }
   task_manager.Resume();
   sprintf(tmp, "# SUCCESS CREATING %s task! task_size():%d..\n",
       tskType,
@@ -971,6 +1045,8 @@ bool test_task(TaskManager& task_manager,
     return test_task_manip(task_manager,waypoints);
   case 7:
     return test_task_random(task_manager,waypoints,n_points);
+  case 8:
+    return test_task_mat(task_manager,waypoints);
   default:
     return false;
   }
